@@ -4,9 +4,9 @@
 # i)  should allow for multiple k (OK)
 # ii) need paralell programing (Partly Ok it works 
 #      but I am not sure what happends when use  widows)
-# iii) cat() can be better  (OK) but it does not works for parallel
+# iii) cat() can be better (OK) but it does not works for parallel
 # vi) output should be a matrix (OK)) with some functionality (see odrered function) 
-# v) create new list for fitting all possible distribution with different 
+# v)  create new list for fitting all possible distribution with different 
 #    parametrizations (OK)
 #------------------------------------------------------------------------
 #------------------------------------------------------------------------
@@ -122,7 +122,7 @@ chooseDist <- function(object,
     m1 <- try(update(object,family=dist, trace=FALSE,...), silent=TRUE)
     if (any(class(m1)%in%"try-error")) 
     { 
-      m1 <-  try(update(object,family=dist, trace=FALSE, ...),  silent=TRUE)
+    m1 <- try(update(object,family=dist, trace=FALSE, ...),  silent=TRUE)
     }
     else
     {
@@ -199,12 +199,12 @@ getOrder <- function(obj, column=1)
 #   if (is.null(rand)&&is.null(newdata)) stop("rand or newdata should be set")
 #   if (!is.null(rand)&&!is.null(newdata)) stop("only rand or newdata should be set NOT both")
 #   DIST <- switch(type, "realAll"=.realAll, 
-#                  "realline"=.realline, 
-#                  "realplus"=.realplus,
-#                  "real0to1"=.real0to1,
-#                  "counts"=.counts,
-#                  "binom"=.binom, 
-#                  "extra"=extra)
+#                       "realline"=.realline, 
+#                       "realplus"=.realplus,
+#                       "real0to1"=.real0to1,
+#                         "counts"=.counts,
+#                          "binom"=.binom, 
+#                          "extra"=extra)
 #   if (type=="extra"&&is.null(extra)) stop("extra is not set")
 #   if  (!is.null(extra)) DIST <- unique(c(DIST, extra))
 #   ##   
@@ -244,3 +244,114 @@ getOrder <- function(obj, column=1)
 # }
 # #--------------------------------------------------------------------------------------
 # #--------------------------------------------------------------------------------------
+#--------------------------------------------------------------------------------------
+#--------------------------------------------------------------------------------------
+chooseDistPred <- function(object,
+                           type = c("realAll", "realline", "realplus","real0to1","counts", "binom", "extra" ), 
+                           extra = NULL,  # for extra distributions to include 
+                           trace = FALSE,
+                           parallel = c("no", "multicore", "snow"), #
+                           ncpus = 1L, #integer: number of processes to be used in parallel operation: typically one would chose this to the number of available CPUs
+                           cl = NULL, # An optional parallel or snow cluster for use if parallel = "snow". If not supplied, a cluster on t     
+                           newdata = NULL,
+                           rand = NULL,
+                           ...)
+{
+  ## get the type of distribution
+  newData <- if(is.null(newdata)) FALSE else TRUE
+  type <- match.arg(type)
+  if (is.null(rand)&&is.null(newdata)) stop("rand or newdata should be set")
+  if (!is.null(rand)&&!is.null(newdata)) stop("only rand or newdata should be set NOT both")
+  DIST <- switch(type, "realAll"=.realAll,
+                 "realline"=.realline,
+                 "realplus"=.realplus,
+                 "real0to1"=.real0to1,
+                 "counts"=.counts,
+                 "binom"=.binom,
+                 "extra"= extra)
+  if (type=="extra"&&is.null(extra)) stop("extra is not set")
+  if  (!is.null(extra)) DIST <- unique(c(DIST, extra))
+  ##
+  m0 <- object
+  tgd0 <- getTGD(m0, newdata=newdata)
+  AiC  <- rep(NA, 1)
+  #--------------- PARALLEL-------------------------------------------------------
+  #----------------SET UP PART----------------------------------------------------
+  parallel <- match.arg(parallel)
+  have_mc <- have_snow <- FALSE
+  if (parallel != "no" && ncpus > 1L) 
+  {
+    if (parallel == "multicore") 
+      have_mc <- .Platform$OS.type != "windows"
+    else if (parallel == "snow") 
+      have_snow <- TRUE
+    if (!have_mc && !have_snow) 
+      ncpus <- 1L
+    loadNamespace("parallel")
+  } 
+  # -------------- finish parallel------------------------------------------------     
+  # define the function
+  fun <- function(dist)
+  {
+    m1 <- try(update(object,family=dist, trace=FALSE,...), silent=TRUE)
+    if (any(class(m1)%in%"try-error"))
+    {
+      m1 <- try(update(object,family=dist, trace=FALSE, ...),  silent=TRUE)
+    }
+    else
+    {
+      tgd1 <- getTGD(m1, newdata=newdata)
+      if (trace)     cat(dist, "\n", tgd1$TGD, "\n")
+      AiC <- tgd1$TGD
+      # if (TGD(tgd1) < TGD(tgd0))
+      # {
+      #   m0 <<- m1 # saving the best model according to k[order.by]
+      # }
+    }
+    c(AiC)        # autput of the function
+  }
+  #----------------------------------------------------------------    
+  #----------------------------------------------------------------
+  #----------------------------------------------------------------
+  # --------  parallel --------------------------------------------
+  MM <- if (ncpus > 1L && (have_mc || have_snow)) 
+  {
+    if (have_mc) 
+    {# sapply(scope, fn)
+      unlist(parallel::mclapply(DIST, fun, mc.cores = ncpus))
+    }
+    else if (have_snow) 
+    {
+      list(...)
+      if (is.null(cl)) 
+      { # make the cluster
+        if (.Platform$OS.type == "windows")
+        {
+          cl <- parallel::makePSOCKcluster(rep("localhost", ncpus))
+          clusterEvalQ(cl,pacman::p_load(gamlss)) 
+          exp.data =  paste0(object$call$data)
+          clusterExport(cl, c(ls(envir = .GlobalEnv), exp.data))
+        } else cl <- parallel::makeForkCluster(ncpus)
+        if (RNGkind()[1L] == "L'Ecuyer-CMRG") 
+          parallel::clusterSetRNGStream(cl)
+        res <-  unlist((parallel::parLapply(cl, DIST, fun)))
+        parallel::stopCluster(cl)
+        res
+      } 
+      else parallel::parLapply(cl, DIST, fun)# use existing cluster
+    }
+  }# end parallel -----
+  else  sapply(DIST, fun) 
+  #----------------------------------------------------------------  
+  #----------------------------------------------------------------         
+  names(MM) <- DIST
+  #----------------------------------------------------------------
+  ## save it in the final model
+  #m0$TGD <- MM[order(MM)]
+  #----------------------------------------------------------------
+  #----------------------------------------------------------------
+  MM[order(MM)]
+}
+#--------------------------------------------------------------------------------------
+#--------------------------------------------------------------------------------------
+
