@@ -82,7 +82,7 @@ dim1newdata  <- dim(dataValid)[1]
  {                   #if `newdata'  is set do this ----------------------------------
           m1 <- gamlss(formula = formula, sigma.formula = sigma.formula, 
                       nu.formula = nu.formula, tau.formula = tau.formula, 
-                      data = data, family = family, control = control, ...)
+                      data = data, family = NO, control = control, ...)
      nfitted <- predictAll(m1, newdata=newdata, data=data)
 dim1newdata  <- dim(newdata)[1]
  }
